#include "login1manager.h"

Login1Manager::Login1Manager() : Login1()
{
	QString service = "org.freedesktop.login1";
	_path = "/org/freedesktop/login1";
	_interface = "org.freedesktop.login1.Manager";

	QDBusConnection::systemBus().connect( service, _path, _interface, "SessionNew", this, SLOT(sessionNewSlot(QString,QDbusObjectPath)) );
	QDBusConnection::systemBus().connect( service, _path, _interface, "SessionRemoved", this, SLOT(sessionRemovedSlot(QString,QDbusObjectPath)) );
	QDBusConnection::systemBus().connect( service, _path, _interface, "UserNew", this, SLOT(userNewSlot(QString,QDbusObjectPath)) );
	QDBusConnection::systemBus().connect( service, _path, _interface, "UserRemoved", this, SLOT(userRemovedSlot(QString,QDbusObjectPath)) );
	QDBusConnection::systemBus().connect( service, _path, _interface, "SeatNew", this, SLOT(seatNewSlot(QString,QDbusObjectPath)) );
	QDBusConnection::systemBus().connect( service, _path, _interface, "SeatRemoved", this, SLOT(seatRemovedSlot(QString,QDbusObjectPath)) );
	Logger::logDebug("Connected dbus signals");
}

QList<Session> Login1Manager::listSessions()
{
	QList<Session> sessions;

	QDBusInterface * dbus = interface();

	if ( ! dbus->isValid() )
	{
		delete dbus;
		return sessions;
	}

	qDBusRegisterMetaType<Session>();
	qDBusRegisterMetaType<QList<Session>>();

	QDBusReply<QList<Session>> servicesReply = dbus->call("ListSessions");

	if ( ! servicesReply.isValid())
	{
		qDebug() << "dBus reply for ListSessions is not valid: " << servicesReply.error().message();
		delete dbus;
		return sessions;
	}

	sessions = servicesReply.value();

	delete dbus;

	return sessions;
}

QList<Seat> Login1Manager::listSeats()
{
	QList<Seat> seats;

	QDBusInterface * dbus = interface();

	if ( ! dbus->isValid() )
	{
		delete dbus;
		return seats;
	}

	qDBusRegisterMetaType<Seat>();
	qDBusRegisterMetaType<QList<Seat>>();

	QDBusReply<QList<Seat>> seatsReply = dbus->call("ListSeats");

	if ( ! seatsReply.isValid())
	{
		qDebug() << "dBus reply for ListSeats is not valid: " << seatsReply.error().message();
		delete dbus;
		return seats;
	}

	seats = seatsReply.value();

	delete dbus;

	return seats;
}

QString Login1Manager::currentSessionPath()
{
	QDBusObjectPath sessionPath;

	QDBusInterface * dbus = interface();

	if ( ! dbus->isValid() )
	{
		delete dbus;
		return QString();
	}

	uint pid = (uint)getpid();

	QDBusReply<QDBusObjectPath> seatsReply = dbus->call("GetSessionByPID", pid);

	if ( ! seatsReply.isValid())
	{
		qDebug() << "dBus reply for GetSessionByPID is not valid: " << seatsReply.error().message();
		delete dbus;
		return QString();
	}

	sessionPath = seatsReply.value();

	delete dbus;

	return sessionPath.path();
}

bool Login1Manager::releaseSession(QString sessionId)
{
	bool ret = false;

	QDBusInterface * dbus = interface();

	if ( ! dbus->isValid() )
	{
		delete dbus;
		return ret;
	}

	QDBusReply<bool> reply = dbus->call("ReleaseSession", sessionId);

	if ( ! reply.isValid())
	{
		qDebug() << "dBus reply for ReleaseSession is not valid: " << reply.error().message();
		delete dbus;
		return ret;
	}

	ret = reply.value();

	delete dbus;

	return ret;
}

bool Login1Manager::activateSession(QString sessionId)
{
	bool ret = false;

	QDBusInterface * dbus = interface();

	if ( ! dbus->isValid() )
	{
		delete dbus;
		return ret;
	}

	QDBusReply<bool> reply = dbus->call("ActivateSession", sessionId);

	if ( ! reply.isValid())
	{
		qDebug() << "dBus reply for ActivateSession is not valid: " << reply.error().message();
	} else {
		ret = true;
	}

	delete dbus;

	return ret;
}

bool Login1Manager::activateSessionOnSeat(QString sessionId, QString seatId)
{
	bool ret = false;

	QDBusInterface * dbus = interface();

	if ( ! dbus->isValid() )
	{
		delete dbus;
		return ret;
	}

	QDBusReply<bool> reply = dbus->call("ActivateSessionOnSeat", sessionId, seatId);

	if ( ! reply.isValid())
	{
		qDebug() << "dBus reply for ActivateSessionOnSeat is not valid: " << reply.error().message();
	} else {
		ret = true;
	}

	delete dbus;

	return ret;
}

bool Login1Manager::suspend(bool interactive)
{
	bool ret = false;

	QDBusInterface * dbus = interface();

	if ( ! dbus->isValid() )
	{
		delete dbus;
		return ret;
	}

	qDBusRegisterMetaType<bool>();
	QDBusReply<void> suspendReply = dbus->call("Suspend", interactive);

	if ( ! suspendReply.isValid())
	{
		qDebug() << "dBus reply for Suspend is not valid: " << suspendReply.error().message();
	} else {
		ret = true;
	}

	delete dbus;

	return ret;
}

void Login1Manager::sessionNewSlot(QString sessionId, QDBusObjectPath objectPath)
{
	Logger::logDebug( QString( "id: %1 path: %2" ).arg( sessionId ).arg( objectPath.path() ) );
	emit sessionNew( sessionId, objectPath );
}

void Login1Manager::sessionRemovedSlot(QString sessionId, QDBusObjectPath objectPath)
{
	Logger::logDebug( QString( "id: %1 path: %2" ).arg( sessionId ).arg( objectPath.path() ) );
	emit sessionRemoved( sessionId, objectPath );
}

void Login1Manager::seatNewSlot(QString seatId, QDBusObjectPath objectPath)
{
	Logger::logDebug( QString( "id: %1 path: %2" ).arg( seatId ).arg( objectPath.path() ) );
	emit seatNew( seatId, objectPath );
}

void Login1Manager::seatRemovedSlot(QString seatId, QDBusObjectPath objectPath)
{
	Logger::logDebug( QString( "id: %1 path: %2" ).arg( seatId ).arg( objectPath.path() ) );
	emit seatRemoved( seatId, objectPath );
}

void Login1Manager::userNewSlot(QString uid, QDBusObjectPath objectPath)
{
	Logger::logDebug( QString( "id: %1 path: %2" ).arg( uid ).arg( objectPath.path() ) );
	emit userNew( uid, objectPath );
}

void Login1Manager::userRemovedSlot(QString uid, QDBusObjectPath objectPath)
{
	Logger::logDebug( QString( "id: %1 path: %2" ).arg( uid ).arg( objectPath.path() ) );
	emit userRemoved( uid, objectPath );
}
