#ifndef LOGINSCREEN_H
#define LOGINSCREEN_H

#include <QApplication>
#include <QDesktopWidget>
#include <QWidget>
#include <QPixmap>
#include <QPropertyAnimation>
#include <QDir>
#include <QSettings>
#include <QTime>
#include <QDate>
#include <QLabel>
#include <QTimer>
#include <QLineEdit>
#include <QPoint>
#include <QSize>
#include <QComboBox>
#include <QPushButton>
#include <QProcess>
#include <QMenu>
#include <QInputDialog>
#include <QProxyStyle>
#include <QScreen>
#include <QNetworkInterface>
#include <QProgressDialog>
#include <QHostInfo>
#include <QList>

#include "pixmapframe.h"
#include "constants.h"
#include "sessionmanager.h"
#include "power.h"
#include "settings.h"
#include "sessionsetting.h"
#include "computersetting.h"

#if defined(Q_OS_LINUX) || defined(Q_OS_FREEBSD)
#include <liblwnet/networkmanager.h>
#include <librework-client/clientsession.h>
#include <librework-client/clientsettings.h>
#endif

class MenuStyle : public QProxyStyle
{
public:
	MenuStyle(int iconSize = 24) { smallIconSize = iconSize; };
	int pixelMetric(PixelMetric metric, const QStyleOption * option = 0, const QWidget * widget = 0 ) const
	{
		switch( metric )
		{
		case QStyle::PM_SmallIconSize:
		case QStyle::PM_ButtonIconSize:
		case QStyle::PM_IconViewIconSize:
		case QStyle::PM_ListViewIconSize:
		case QStyle::PM_ToolBarIconSize:
		case QStyle::PM_LargeIconSize:
			return smallIconSize;
		default:
			return QProxyStyle::pixelMetric( metric, option, widget );
		}
	}
private:
	int smallIconSize;
};

class LoginScreen : public QWidget
{
	Q_OBJECT

public:
	LoginScreen( QWidget * parent = nullptr );
	~LoginScreen();

	QPixmap selectPixmap( QString configurationFile );

public slots:
	void mouseOrKeyboardAction(QKeyEvent *event = nullptr);
	void doAnimation();
	void doInitScreen();
	void animationFinished();
	void setDateTime();
	void passwordTextChanged(const QString &);
	void finishSession( int status );
	void hideSlot();

private slots:
	void usernameLineEditTextChanged(QString text);
	void loginButtonClicked();
	void serverChanged(QString server);
	void doSmartCardLogin(QString cardNumber);
	void clearPressedKeys();
	void showWifiMenu();
	void selectWifi(QAction * action);
	void updateNetwork();

private:
	void forceTranslations();
	QString selectConfigurationFile();
	void initInitScreen();
	void initUserControls();
	void showUserControls(bool show);
	void setShutdownMenu();
	QStringList getMacAddresses();
	bool checkPressedKeys();

	QString menuStyleSheet;
	QTimer * timer;
	QTimer * loginScreenTimeout;
	QPropertyAnimation * animation;
#if defined(Q_OS_LINUX) || defined(Q_OS_FREEBSD)
	ClientSession * clientSession;
#endif
	QList<SessionSetting> sessionSettings;
	QMenu * wifiMenu;
	QMenu * ethernetMenu;
	QMenu * vpnMenu;
	PixmapFrame * pixmapFrame;
	QList<QLabel*> background;
	QLabel * dateTimeLabel;
	QLabel * logoLabel;
	QLineEdit * usernameLineEdit;
	QLineEdit * passwordLineEdit;
	QComboBox * serverComboBox;
	QPushButton * loginButton;
	QPushButton * wifiButton;
	QPushButton * ethernetButton;
	QPushButton * vpnButton;
	QPushButton * exitButton;

	QScreen * screen;

	QString username;

	QString pressedKeys;
	QTimer * pressedKeysTimer;

	NetworkManager * networkManager;
	QTimer * networkTimer;
};


#endif
