#include "lwclient.h"

SOCKET LWClient::tcpSocket = 0;
bool LWClient::_isConnected = false;
QMutex LWClient::mutex;

void LWClient::close()
{
	if ( _isConnected )
	{
		QString message = "quit\n";
		sendMessage( message );
	}
	LWSocket::closeSocket( tcpSocket );
}

bool LWClient::connect(QString address, int port)
{
	int _port = port;
	if ( _port == -1 )
	{
		_port = LIBREWORK_SERVER_DEFAULT_PORT;
	}
	if ( address.isEmpty() )
	{
		return false;
	}

	qDebug("Connecting to %s:%d", address.toUtf8().data(), _port);

	tcpSocket = LWSocket::createRemoteSocket( address, _port );

	if ( tcpSocket < 0)
	{
		qDebug("Cannot create client socket (error %d)", tcpSocket);
		_isConnected = false;
	} else {
		qDebug("Connected");
		_isConnected = true;
	}

	return _isConnected;
}

bool LWClient::authenticate(QString username, QString password)
{
	if (_isConnected )
	{
		// Authentication
		QString message = "login?" + username + "&&" + password + "\n";
		QString response;
		bool status = LWSocket::sendMessage( tcpSocket, message );
		if ( status )
		{
			response = LWSocket::receiveMessage( tcpSocket );
		}

		if ( ! status || response.startsWith( "Error" ) || response.isEmpty() )
		{
			return false;
		} else {
			return true;
		}
	} else {
		return false;
	}
}

QString LWClient::sendMessage(QString message)
{
	mutex.lock();

	QString response;

	if ( _isConnected )
	{
		if ( LWSocket::sendMessage( tcpSocket, message ) )
		{
			response = LWSocket::receiveMessage( tcpSocket );
		}
		response = response.trimmed();
	}

	mutex.unlock();

	return response;
}

QString LWClient::sendMessage(QString command, QStringList parameters)
{
	return LWClient::sendMessage( command + "?" + parameters.join("&") );
}
