#if defined(Q_OS_LINUX) || defined(Q_OS_FREEBSD)
#include <unistd.h>
#include <sys/types.h>
#endif

#include <QApplication>
#include <QStyle>
#include <QStyleFactory>
#include <QTranslator>
#include <QProcess>
#include <QFontDatabase>
#include <QFont>
#include <QDir>

#include "constants.h"
#include "loginscreen.h"
#include "settings.h"
#include "pam.h"
#include "logger.h"
#include "xserver.h"

int main(int argc, char * argv[])
{
	qint64 pid = -1;
	int display = -1;
	QProcess * process = XServer::launchServer( &pid, &display );
	if ( process != nullptr && pid != -1 && display != -1 )
	{
		qputenv( "DISPLAY", ":" + QString::number( display ).toUtf8() );
	} else {
		qDebug( "Cannot start Xorg server" );
		exit(1);
	}
	QApplication qApplication(argc, argv);
	qApplication.setQuitOnLastWindowClosed( false );

#ifdef Q_OS_WIN
	QString username = qgetenv("USERNAME");
#else
	QString username = qgetenv("USER");
#endif
	QDir fontsDir( LIBREWORK_FONT_DIR );
	QStringList fontFile = fontsDir.entryList(QStringList("*.ttf"));
	QList<int> fontId;
	for (int i = 0; i < fontFile.count(); i++)
	{
		fontId.append( QFontDatabase::addApplicationFont( LIBREWORK_FONT_DIR + QString(QDir::separator()) + fontFile.at(i) ) );
	}

	if ( fontId.count() > 0 )
	{
		QFontDatabase fontDatabase;
		QString family = QFontDatabase::applicationFontFamilies(fontId.at(0)).at(0);
		QFont font = fontDatabase.font( LIBREWORK_FONT, QString::null, LIBREWORK_FONT_BASE_SIZE );
		qApplication.setFont( font );
	}

	QStyle *style = QStyleFactory::create("plastique");

	if(style)
	{
		QApplication::setStyle(style);
	}

#if defined(Q_OS_LINUX) || defined(Q_OS_FREEBSD)
	QString program("setxkbmap");
	QStringList arguments;
	arguments += "-layout";
	arguments += Settings::getKeyboardValue( "XKBLAYOUT" );

	QProcess::execute( program, arguments );
#endif

	QString initProgram = Settings::getValue( "StartOnInit" ).toString();
	if ( ! initProgram.isEmpty() )
	{
		QProcess::startDetached( initProgram );
	}

	QTranslator translator;

	QString lang = Settings::getLocaleValue("LANG", "es");
	QString locale = lang.section('_', 0, 0);

	if (translator.load( locale ))
	{
		qApplication.installTranslator(&translator);
	}

#if defined(Q_OS_LINUX) || defined(Q_OS_FREEBSD)
	qputenv("LANG", lang.toUtf8());
#endif

	int ret;
#if defined(Q_OS_LINUX) || defined(Q_OS_FREEBSD)
	if ( true || getuid() == 0 )
	{
		Pam::startPam( true, "librework-displaymanager-greeter", "root" );
		if ( Pam::openSession( "greeter", "seat0" ) )
		{
			LoginScreen * loginScreen = new LoginScreen();
			loginScreen->show();
			ret = qApplication.exec();
			qDebug("Stariting multimon");
			QString command = "/usr/bin/multimon.sh";
			QStringList args = QStringList() << "duplicate";
			ret = QProcess::execute( command, args );
			qDebug("Result: %d", ret);
			qDebug("Started");
			delete loginScreen;
		} else {
			Logger::logError("Cannot open session for greeter");
			ret = 2;
		}
	} else {
#endif
		ret = 1;
#if defined(Q_OS_LINUX) || defined(Q_OS_FREEBSD)
	}
#endif

	return ret;
}
