#ifndef PIXMAPFRAME_H
#define PIXMAPFRAME_H

#include <QFrame>
#include <QPainter>
#include <QPixmap>
#include <QPaintEvent>
#include <QMouseEvent>
#include <QKeyEvent>
#include <QFont>
#include <QColor>

#include "constants.h"

class PixmapFrame : public QFrame
{
	Q_OBJECT

	Q_PROPERTY(qreal opacity READ opacity WRITE setOpacity)
	Q_PROPERTY(QColor color READ color WRITE setColor)

	public:
		PixmapFrame(QWidget * parent = 0, QPixmap pixmap = QPixmap());

		void setOpacity(qreal opacity);
		qreal opacity();
		void setColor( QColor color );
		QColor color();

		void setPixmap(QPixmap pixmap, bool centered, bool expanded );
		void setText( QString timeText, QString dateText );
		void setTextPos( int posX, int posY );
		void setFontFamily( QString fontFamily );
		void setTimeFontPixelSize( int pixelSize );
		void setDateFontPixelSize( int pixelSize );
		void setFontColor( QColor fontColor );

	public slots:
		void resize();
		void showText(bool enable);

	signals:
		void mousePressed();
		void mouseMoved();
		void escapePressed();
		void keyPressed(QKeyEvent * event);

	protected:
		void mousePressEvent(QMouseEvent *);
		void mouseMoveEvent(QMouseEvent *);
		void keyPressEvent(QKeyEvent *event);
		void paintEvent (QPaintEvent *);

	private:
		QColor _color;
		qreal _opacity;
		QPixmap pixmap;
		QString timeText;
		QString dateText;
		int textPosX;
		int textPosY;
		int timeTextPixelSize;
		int dateTextPixelSize;
		QString fontFamily;
		QColor fontColor;
		int x, y;
		bool centered;
		bool expanded;
		bool enableText;
};

#endif
