#ifndef SESSION_H
#define SESSION_H

#include <QApplication>
#include <QByteArray>
#include <QString>
#include <QFile>
#include <QDir>
#include <QProcess>
#include <QWidget>
#include <QStandardPaths>
#include <QObject>
#include <QTranslator>
#include <QTextStream>
#include <QDBusMessage>
#include <QDBusInterface>
#include <QMessageBox>
#include <QCryptographicHash>

#include "settings.h"
#include "loginscreen.h"
#include "lwclient.h"
#include "constants.h"
#include "logger.h"

class LoginScreen;

#include <librework-client/clientsession.h>

#include <sys/stat.h>
#include <sys/types.h>
#include <unistd.h>
#include <grp.h>
#include <pwd.h>
#include <security/pam_appl.h>

class Session : public QObject
{
	public:
		static int functionConversation(int numMsg, const struct pam_message **msg, struct pam_response ** resp, void *appdata_ptr);
		static bool authenticateSystemUser( QString username, QString password );

		static void getUserAndGroupIds( QString username, int * uid, int * gid );
		static QString getUserHome( QString username );
		static int setCurrentDir(const char *dirname);
		static QString createHome( QString homes, QString username );
		static bool switchUser(QString homes, QString username );
		static void createGoogleChromeDir( QString sourceDir );
		static void syncGoogleChromeDir( QString username );
		static void createHomeLinks(QString sourceDir, QString homeDir, QString username);
		static void createDesktopLinks(QString homeDir, QString username, bool setPermissions = false);
		static bool createSystemUser(int uid, QString homes, QString username, QString password );
		static bool openSession();
		static bool closeSession();
		static QStringList launch(QString username, QString password, QString serverAddress, int port, LoginScreen * parent, QString remoteServer = QString::null);
		static bool connectToServer(QString serverAddress, int serverPort);
		static QString credentialsFile(QString username, QString password);
		static bool mountSmbHome(QString username, QString password);
		static bool mountSmbShares(QString username, QString password);
		static bool smbMount(QString username, QString credentialsFile, QString smbPath, QString targetPath);
		static void smbUmountAll();
		static void mountHome();
		static void umountHome();
		static void writeToken( QString username, QString homeDir, QString token );

	private:
		static QWidget * parentWidget;
		static QString sourceDir;
		static QString targetDir;
};

#endif //SESSION_H
