#ifndef SESSIONMANAGER_H
#define SESSIONMANAGER_H

#include <QApplication>
#include <QByteArray>
#include <QString>
#include <QFile>
#include <QDir>
#include <QProcess>
#include <QWidget>
#include <QStandardPaths>
#include <QObject>
#include <QTranslator>
#include <QTextStream>
#include <QDBusMessage>
#include <QDBusInterface>
#include <QMessageBox>
#include <QCryptographicHash>

#include "pam.h"
#include "login1manager.h"
#include "dbussession.h"
#include "sysuser.h"
#include "settings.h"
#include "shares.h"
#include "loginscreen.h"
#include "lwclient.h"
#include "constants.h"
#include "logger.h"
#include "sessionsetting.h"
#include "sharesetting.h"

class LoginScreen;

#include <librework-client/clientsession.h>

#include <sys/stat.h>
#include <sys/types.h>
#include <unistd.h>
#include <grp.h>
#include <pwd.h>

class SessionManager : public QObject
{
	public:
		static int setCurrentDir(const char *dirname);
		static bool switchUser(QString homes, QString username );
		static bool checkBlackList(QString username, SessionSetting sessionSetting);
		static bool checkWhiteList(QString username, SessionSetting sessionSetting);
		static bool authenticateSessionUser( QString username, QString password, SessionSetting sessionSetting );
		static bool mountSessionUserHome( QString username, QString password, SessionSetting sessionSetting );
		static bool mountSessionUserShares( QString username, QString password, SessionSetting sessionSetting );
		static QStringList launch(QString username, QString password, SessionSetting sessionSetting, LoginScreen * parent);
		static bool connectToServer(QString serverAddress, int serverPort);
		static void mountHome();
		static void umountHome();
		static bool launchSessionDesktop(QString username, QString password, SessionSetting sessionSetting, LoginScreen * parent);

	private:
		static QWidget * parentWidget;
		static QString sourceDir;
		static QString targetDir;
		static Login1Manager login1Manager;
};

#endif //SESSIONMANAGER_H
