#include "sessionsetting.h"

SessionSetting::SessionSetting(int id, QString name, QIcon icon, QString desktop, QString authentication, QString clientSession, QList<ShareSetting> shares, ComputerSetting computers, QStringList blackList, QStringList whiteList)
{
	_id = id;
	_name = name;
	_icon = icon;
	_desktop = desktop;
	_authentication = authentication;
	_clientSession = clientSession;
	_shares = shares;
	_computers = computers;
	_blackList = blackList;
	_whiteList = whiteList;
}

QList<SessionSetting> SessionSetting::getSessionSettings()
{
	int lastId = 0;
	QList<SessionSetting> ret;

	QStringList keys = Settings::getKeys();
	for ( int i = 0; i < keys.count(); i++ )
	{
		QString name = keys[i];

		QIcon icon = QIcon( ":/icons/thishost.png" );

		QString desktop = Settings::getValue( keys[i] + "/Desktop" ).toString();
		if ( desktop.toLower().startsWith( "rdp://" ) )
		{
			icon = QIcon( ":/icons/librework-server.png" );
		}
		if ( desktop.startsWith( "/" ) && desktop.contains( "xfce" ) )
		{
			icon = QIcon( ":/icons/xfce.png" );
		}
		if ( desktop.startsWith( "/" ) && desktop.contains( "gnome" ) )
		{
			icon = QIcon( ":/icons/gnome.png" );
		}
		if ( desktop.startsWith( "/" ) && desktop.contains( "kde" ) )
		{
			icon = QIcon( ":/icons/kde.png" );
		}

		QString authentication = Settings::getValue( keys[i] + "/Authentication" ).toString();
		if ( authentication.toLower().startsWith( "lw://" ) )
		{
			icon = QIcon( ":/icons/librework-server.png" );
		}

		QString clientSession = Settings::getValue( keys[i] + "/Client Session" ).toString();

		QList<ShareSetting> shares;
		QString sharesFile = Settings::getValue( keys[i] + "/Shares" ).toString();
		if ( ! sharesFile.isEmpty() )
		{
			shares = ShareSetting::getShareSettings( sharesFile );
		}

		ComputerSetting computers;
		QString computersFile = Settings::getValue( keys[i] + "/Computers" ).toString();
		if ( ! computersFile.isEmpty() )
		{
			computers = ComputerSetting::getComputerSettings( computersFile );
		}

		QString blackListFileName = Utils::absoluteConfigFilePath( Settings::getValue( keys[i] + "/BlackList" ).toString() );
		QStringList blackList;
		if ( ! blackListFileName.isEmpty() )
		{
			blackList = Utils::fileToStringList( blackListFileName );
		}
		QString whiteListFileName = Utils::absoluteConfigFilePath( Settings::getValue( keys[i] + "/WhiteList" ).toString() );
		QStringList whiteList;
		if ( ! whiteListFileName.isEmpty() )
		{
			whiteList = Utils::fileToStringList( whiteListFileName );
		}

		ret += SessionSetting( lastId++, name, icon, desktop, authentication, clientSession, shares, computers, blackList, whiteList );
	}

	return ret;
}

bool SessionSetting::isRemote()
{
	return _desktop.toLower().startsWith( "rdp://" );
}

bool SessionSetting::isLibrework()
{
	return _authentication.toLower().startsWith( "lw://" );
}

bool SessionSetting::isLocal()
{
	return _authentication.toLower().simplified() == "local";
}
