#include "settings.h"

QString Settings::getKeyboardValue( QString key, QString defaultValue )
{
	return getDefaultFileValue( "/etc/default/keyboard", key, defaultValue );
}

QString Settings::getLocaleValue( QString key, QString defaultValue )
{
	return getDefaultFileValue( "/etc/default/locale", key, defaultValue );
}

QString Settings::getDefaultFileValue( QString file, QString key, QString defaultValue )
{
	QFile confFile( file );
	bool found = false;

	confFile.open( QIODevice::ReadOnly );

	QByteArray line;
	while ( ! found )
	{
		line = confFile.readLine();
		QString start = key + "=";
		if ( line.trimmed().startsWith( start.toUtf8() ) )
		{
			found = true;
		}
	}

	QString ret;

	if ( found )
	{
		ret =  QString( line ).section( '=', 1, 1 ).simplified();
	} else {
		ret = defaultValue;
	}

	return ret;
}

QVariant Settings::getValue( QString key, QVariant defaultValue )
{
	QSettings settings( CONFIG_FILE, QSettings::IniFormat );
	return settings.value( key, defaultValue );
}

QStringList Settings::getKeys( QString group )
{
	QSettings settings( CONFIG_FILE, QSettings::IniFormat );
	if ( ! group.isEmpty() )
	{
		settings.beginGroup( group );
		return settings.childKeys();
	} else {
		return settings.childGroups();
	}
}

void Settings::setValue( QString key, QVariant value )
{
	QSettings settings( CONFIG_FILE, QSettings::IniFormat );
	settings.setValue( key, value );
	settings.sync();
}
