#include "shares.h"

QString Shares::credentialsFile(QString username, QString password, QString domain, QString separator )
{
	QDir tmp( QStandardPaths::writableLocation( QStandardPaths::TempLocation ) );
	tmp.mkdir( ".librework" );
	QString fileName = QStandardPaths::writableLocation( QStandardPaths::TempLocation )
				+ QString(QDir::separator())
				+ ".librework"
				+ QDir::separator()
				+ ".credentials";
	QFile file(fileName);
	file.setPermissions(QFileDevice::ReadOwner | QFileDevice::WriteOwner);
	file.open(QFile::WriteOnly);
	file.write(QString("username" + separator + username + "\n").toUtf8());
	file.write(QString("password" + separator + password + "\n").toUtf8());
	file.write(QString("domain" + separator + domain + "\n").toUtf8());
	file.close();

	return fileName;
}

bool Shares::mountShare(QString username, QString password, QString domain, QString homeDir, ShareSetting shareSetting)
{
	if ( shareSetting.protocol().toLower() == "local" )
	{
		return true;
	}
	if ( shareSetting.protocol().toLower() == "smb" )
	{
		return mountSmbShare( username, password, domain, homeDir, shareSetting );
	}
	if ( shareSetting.protocol().toLower() == "ssh" )
	{
		return mountSshShare( username, password, domain, homeDir, shareSetting );
	}
	return false;
}

bool Shares::mountSshShare(QString username, QString password, QString domain, QString homeDir, ShareSetting shareSetting)
{
	return false;
}

bool Shares::mountSmbShare(QString username, QString password, QString domain, QString homeDir, ShareSetting shareSetting)
{
	bool ret = false;

	QString source = "//" + shareSetting.serverAddress() +
			shareSetting.sourcePath()
			.replace( "${USER}", username )
			.replace( "${HOME}", homeDir )
			.replace( "${DOMAIN}", domain );

	QString target;
	if ( shareSetting.isHome() )
	{
		target = homeDir;
	} else {
		target = shareSetting.targetDir() + shareSetting.targetPath();
		target = target
			.replace( "${USER}", username )
			.replace( "${HOME}", homeDir )
			.replace( "${DOMAIN}", domain );
	}
	Logger::logInfo( QString( "Mounting %1 on %2" ).arg( source ).arg( target ) );

	QDir("/").mkpath( target );
	if ( QFile::exists( target ) && QFileInfo( target ).isDir() )
	{
		if ( smbMount( username, password, domain, source, target ) )
		{
			qputenv("HOME", homeDir.toUtf8());
			qputenv("USER", username.toUtf8());
			//createHomeLinks( homeDir, homeDir, username );
			Logger::logInfo( "Mount succesful" );
			ret = true;
		} else {
			Logger::logError( "Mount failed" );
			if ( QFileInfo( target ).isDir() )
			{
				if ( QDir( target ).isEmpty() )
				{
					QDir( target ).removeRecursively();
				}
			}
		}
	} else {
		Logger::logError( QString( "Cannot create target path %1" ).arg( target ) );
	}

	return ret;
/*
	// Mount shares
	bool ret = true;
	Logger::logInfo("Mounting shares...");
	QString baseClientPath = QStandardPaths::writableLocation( QStandardPaths::TempLocation ) + QDir::separator();
	QString targetHomePath = baseClientPath + username;
	QString targetPath = targetHomePath + "/.shares/";
	QDir("/").mkpath( targetPath );
	QString credentials = credentialsFile( username, password, domain );
	if ( QFile::exists( targetPath ) )
	{
		QStringList drives = LWClient::sendMessage("get_redirect_drives", QStringList( username )).split(",");
		Logger::logInfo( QString( "get_redirect_drives response: '%1'" ).arg( drives.join(',') ) );
		for ( int i = 0; i < drives.count(); i++ )
		{
			if ( ! drives[i].simplified().isEmpty() )
			{
				QString clientPath = drives[i].trimmed().section('=', 0, 0).remove("\\").remove(":").toUpper();
				QString serverPath = drives[i].trimmed().section('=', 1, 1);

				QString mountPoint = serverPath;
				mountPoint = mountPoint.replace("\\", "/");
				mountPoint = mountPoint.section('/', -1) + " (" + clientPath + ")";
				Logger::logInfo( QString( "Trying to mount %1 on %2" ).arg( serverPath ).arg( targetPath + mountPoint ) );

				if ( serverPath.startsWith("\\\\") ) // Shared folder
				{
					serverPath.replace("\\", "/");
					QDir("/").mkpath( targetPath + mountPoint );
					if ( QFile::exists( targetPath + mountPoint ) )
					{
						Logger::logInfo( QString( "Mounting %1 on %2" ).arg( serverPath ).arg( targetPath + mountPoint ) );
						ret = smbMount( username, password, domain, serverPath, targetPath + mountPoint);
						if ( ! ret )
						{
							QDir("/").rmdir( targetPath + mountPoint );
						}
					} else {
						Logger::logWarning( QString( "Cannot create mount point %1" ).arg( targetPath + mountPoint ) );
						ret = false;
					}
				} else { // Client drive redirect
					// Do nothing
					Logger::logInfo( "Client drive redirect. Doing nothing." );
				}
			}
		}
	} else {
		Logger::logWarning( QString ( "Cannot create network shares dir %1. Not mounting shares" ).arg( targetPath ) );
		ret = false;
	}

	// Remove credentials file
	QFile credsFile(credentials);
	credsFile.remove();
	credsFile.close();

	return ret;
*/
}

bool Shares::smbMount(QString username, QString password, QString domain, QString smbPath, QString targetPath)
{
	bool ret = false;
#if defined(Q_OS_LINUX) || defined(Q_OS_FREEBSD)
	int uid, gid;
	SysUser::getUserAndGroupIds(username, &uid, &gid);

	QProcess smbMountProcess;
	QString command = "mount.cifs";
	QStringList parameters;
	QString options = Settings::getValue("Advanced/CIFSMountOptions").toString();
	QString credentials = credentialsFile( username, password, domain );

	if ( options.isEmpty() )
	{
		options = "mfsymlinks,nobrl,cache=strict,actimeo=60,nounix";
	}

	parameters << "-o";
	parameters << options + ",uid=" + QString::number(uid) + "," + "credentials=" + credentials;
	parameters << smbPath;
	parameters << targetPath;

	Logger::logInfo( QString( "Mounting samba dir: %1 %2" ).arg( command ).arg( parameters.join(" ") ) );

	smbMountProcess.start( command, parameters );
	if ( smbMountProcess.waitForStarted() )
	{
		smbMountProcess.waitForFinished();
		ret = ( smbMountProcess.exitCode() == 0 );
	}

	// Remove credentials file
	QFile credsFile(credentials);
	credsFile.remove();
	credsFile.close();
#endif
	return ret;
}

bool Shares::sshMount(QString username, QString password, QString serverAddress, QString sourcePath, QString targetPath)
{
#if defined(Q_OS_LINUX) || defined(Q_OS_FREEBSD)
	int uid, gid;
	SysUser::getUserAndGroupIds(username, &uid, &gid);

	QProcess sshMountProcess;
	QString command = "sshfs";
	QStringList parameters;

	parameters << "-o";
	parameters << "uid=" + QString::number(uid) + ",password_stdin";
	parameters << username + "@" + serverAddress + ":" + sourcePath;
	parameters << targetPath;

	Logger::logInfo( QString( "Mounting ssh dir: %1 %2" ).arg( command ).arg( parameters.join(" ") ) );

	sshMountProcess.start( command, parameters );
	if ( sshMountProcess.waitForStarted() )
	{
		sshMountProcess.write( password.toUtf8() + "\n" );
		sshMountProcess.waitForFinished();
		return ( sshMountProcess.exitCode() == 0 );
	}
#endif
	return false;
}

bool Shares::smbAuth(QString username, QString password, QString domain, QString serverName)
{
	bool ret = false;
#if defined(Q_OS_LINUX) || defined(Q_OS_FREEBSD)
	int uid, gid;
	SysUser::getUserAndGroupIds(username, &uid, &gid);

	QString credentials = credentialsFile( username, password, domain, " = " );
	QProcess smbClientProcess;
	QString command = "smbclient"; //<ServerName> -U <username>
	QStringList parameters;
	parameters << "//" + serverName;
	parameters << "-U";
	parameters << username;
	parameters << "-A";
	parameters << credentials;


	Logger::logInfo( QString( "Checking samba credentials: %1 %2" ).arg( command ).arg( parameters.join(" ") ) );
	smbClientProcess.start( command, parameters );
	if ( smbClientProcess.waitForStarted() )
	{
		smbClientProcess.waitForFinished();
		ret = ( smbClientProcess.exitCode() == 0 );
	}
	// Remove credentials file
	QFile credsFile(credentials);
	credsFile.remove();
	credsFile.close();
#endif
	return ret;
}

void Shares::sshUmountAll()
{
	QProcess * umount = new QProcess();
	QStringList parameters;
	parameters << "-t" << "fuse.sshfs" << "-a";
	umount->start( "umount", parameters );
	umount->waitForStarted();
	umount->waitForFinished();
	delete umount;
}

void Shares::smbUmountAll()
{
	QProcess * umount = new QProcess();
	QStringList parameters;
	parameters << "-t" << "cifs" << "-a";
	umount->start( "umount", parameters );
	umount->waitForStarted();
	umount->waitForFinished();
	delete umount;
}
