#include "sharesetting.h"

ShareSetting::ShareSetting(QString targetDir, bool isHome, bool isPrinter, QString protocol, QString domain, QString serverAddress, QString sourcePath, QString targetPath)
{
	_targetDir = targetDir;
	_isHome = isHome;
	_isPrinter = isPrinter;
	_protocol = protocol;
	_domain = domain;
	_serverAddress = serverAddress;
	_sourcePath = sourcePath;
	_targetPath = targetPath;
}

QList<ShareSetting> ShareSetting::getShareSettings(QString sharesFile)
{
	QList<ShareSetting> ret;
	if ( ! sharesFile.isEmpty() )
	{
		if ( QFileInfo( sharesFile ).isRelative() )
		{
			sharesFile = QString(CONF_DIR) + QDir::separator() + sharesFile;
		}
		QSettings shareSettings( sharesFile, QSettings::IniFormat );
		QString targetDir = shareSettings.value( "/TargetDir" ).toString();
		QStringList entries = shareSettings.childGroups();
		for ( int i = 0; i < entries.count(); i++ )
		{
			if ( entries[i].toLower() != "global" )
			{
				bool isHome = shareSettings.value( entries[i] + "/HomeDir", false ).toBool();
				bool isPrinter = shareSettings.value( entries[i] + "/Printer", false ).toBool();
				QString serverAddress = shareSettings.value( entries[i] + "/Server" ).toString();
				QString protocol = "local";
				if ( serverAddress.contains( "://" ) )
				{
					protocol = serverAddress.section( "://", 0, 0 );
				}
				serverAddress = serverAddress.section( "://", 1, 1 );
				QString domain;
				if ( serverAddress.contains( "@" ) )
				{
					domain = serverAddress.section( "@", 0, 0 );
					serverAddress = serverAddress.section( "@", 1, 1 );
				}
				QString sourcePath = shareSettings.value( entries[i] + "/SourcePath" ).toString();
				QString targetPath = shareSettings.value( entries[i] + "/TargetPath" ).toString();
				ret += ShareSetting( targetDir, isHome, isPrinter, protocol, domain, serverAddress, sourcePath, targetPath );
			}
		}
	}
	return ret;
}
