#include "xserver.h"

QProcess * XServer::launchServer(qint64 * pid, int * display)
{
	bool error = false;
	char fileName[] = TMPDIR "/displaymanager.XXXXXX";
	int fd = mkostemp( fileName, O_CREAT | O_RDWR | S_IRUSR | S_IWUSR );

	if ( fd == -1 )
	{
		qDebug("Cannot open file %s for setting display variable", fileName);
		perror( "Error: " );
		return nullptr;
	}

	QString command = XORGCOMMAND;
	QStringList arguments;
	arguments << "-seat" << "seat0";
	arguments << "-displayfd" << QString::number( fd );
	arguments << "vt7";

	QProcess * process = new QProcess();
	process->setProgram( command );
	process->setArguments( arguments );
	process->startDetached( pid );

	QString buffer;
	QFile file( fileName );
	qint64 now = QDateTime::currentSecsSinceEpoch() + TIMEOUT;
	if ( file.open( QIODevice::ReadOnly ) )
	{
		QTextStream textStream( &file );
		while ( buffer.isEmpty() && now > QDateTime::currentSecsSinceEpoch() )
		{
			buffer = textStream.readLine();
		}
		if ( buffer.isEmpty() ) // TIMEOUT
		{
			error = true;
			qDebug("Timeout opening X server");
		}
		file.close();
	} else {
		error = true;
		qDebug("Cannot open file for reading");
	}

	bool dp;
	int dpInt = buffer.toInt( &dp );

	if ( ! dp )
	{
		error = true;
		qDebug("Cannot convert '%s' to int", buffer.toUtf8().data());
	}

	close(fd);

	QFile( fileName ).remove();

	if ( ! error )
	{
		* display = dpInt;
		* pid = process->pid();
		qDebug("Launching X server with pid %d on DISPLAY :%d",(int) *pid, *display);
		return process;
	} else {
		qDebug("Something failed. Not starting X server");
		process->kill();
		process->waitForFinished();
		delete process;
		return nullptr;
	}
}
